@@ -1,13 +1,13 @@
 /**
  * \file gdinit.c
  *
- *  getdefs Copyright (c) 1999-2011 by Bruce Korb - all rights reserved
+ *  getdefs Copyright (c) 1999-2012 by Bruce Korb - all rights reserved
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *  Time-stamp:        "2011-12-29 10:02:47 bkorb"
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -291,7 +291,7 @@ set_define_re(void)
     static char const pat_wrapper[] = "/\\*=(%s)";
 
     char const * def_pat;
-    ag_bool      free_pat = AG_FALSE;
+    bool      free_pat = false;
 
     /*
      *  Our default pattern is to accept all names following
@@ -317,7 +317,7 @@ set_define_re(void)
          */
         snprintf(bf, len, pat_wrapper, pz);
         def_pat  = bf;
-        free_pat = AG_TRUE;
+        free_pat = true;
     }
 
     /*
